From: Michael R. Crusoe <crusoe@debian.org>
Subject: fix typos
Forwarded: https://github.com/veg/hyphy/pull/1289
--- hyphy.orig/res/TemplateBatchFiles/files.lst
+++ hyphy/res/TemplateBatchFiles/files.lst
@@ -108,4 +108,4 @@
 
 "","Perform relative ratio tests.","!Relative Ratio";
 "RRT","Use relative ratio test on 2 datasets and a variety of standard models","RelativeRatio.bf";
-"PRRTI","Given a list of files (and optinally genetic code tables), perform relative ratio tests on all possible pair of the data files.","PairwiseRelativeRatio.bf";
+"PRRTI","Given a list of files (and optionally genetic code tables), perform relative ratio tests on all possible pair of the data files.","PairwiseRelativeRatio.bf";
--- hyphy.orig/src/core/category.cpp
+++ hyphy/src/core/category.cpp
@@ -177,7 +177,7 @@
                     !CheckEqual (iSplitter->GetMaxX(),1.0) ||
                     *theName == splitterName ||
                     (intervals = iSplitter->GetNumberOfIntervals()+1) < 2) {
-                HandleApplicationError (errorMsg & _String("Category variables which specify interval splitting options must be supported on [0,1], and not result in circular dependance"));
+                HandleApplicationError (errorMsg & _String("Category variables which specify interval splitting options must be supported on [0,1], and not result in circular dependence"));
                 return;
             }
 
@@ -475,7 +475,7 @@
         }
     }
 
     // disallow category -> category dependance
     for (long i=0; i<scannedVarsList.lLength; i++) {
         _Variable * curVar = (_Variable*)variablePtrs (scannedVarsList.list_data[i]);
         if (curVar->IsCategory()) {
@@ -489,7 +489,7 @@
     hiddenMarkovModel = HY_NO_MODEL;
 
     parameterList.Duplicate  (&scannedVarsList);
     // finally go thru all the variables and put them where they belong in dependance containers
 
     _SimpleList     exclude;
 
@@ -475,7 +475,7 @@
     }
 
-    // disallow category -> category dependance
+    // disallow category -> category dependence
     for (long i=0; i<scannedVarsList.lLength; i++) {
         _Variable * curVar = (_Variable*)variablePtrs (scannedVarsList.list_data[i]);
@@ -489,7 +489,7 @@
 
     parameterList.Duplicate  (&scannedVarsList);
-    // finally go thru all the variables and put them where they belong in dependance containers
+    // finally go thru all the variables and put them where they belong in dependence containers
 
     _SimpleList     exclude;
--- hyphy.orig/src/core/likefunc.cpp
+++ hyphy/src/core/likefunc.cpp
@@ -2382,20 +2382,20 @@
 
 //_______________________________________________________________________________________
 
-void      _LikelihoodFunction::RecurseConstantOnPartition (long blockIndex, long index, long dependance, long highestIndex, hyFloat weight, _Matrix& cache) {
+void      _LikelihoodFunction::RecurseConstantOnPartition (long blockIndex, long index, long dependence, long highestIndex, hyFloat weight, _Matrix& cache) {
     // SLKP 20210102: TODO this needs to be reviewed and confirmed as working.
     _CategoryVariable* thisC = (_CategoryVariable*)LocateVar(indexCat.list_data[index]);
 
     if (index<highestIndex) {
-        if ((!CheckNthBit(dependance,index))||thisC->is_hidden_markov()) {
-            RecurseCategory (blockIndex, index+1, dependance,highestIndex,weight);
+        if ((!CheckNthBit(dependence,index))||thisC->is_hidden_markov()) {
+            RecurseCategory (blockIndex, index+1, dependence,highestIndex,weight);
         } else {
             thisC->Refresh();
             long nI = thisC->GetNumberOfIntervals ();
             offsetCounter *= nI;
             for (long k = 0; k<nI; k++) {
                 thisC->SetIntervalValue(k);
-                RecurseConstantOnPartition(blockIndex,index+1,dependance, highestIndex,weight*thisC->GetIntervalWeight(k),cache);
+                RecurseConstantOnPartition(blockIndex,index+1,dependence, highestIndex,weight*thisC->GetIntervalWeight(k),cache);
                 categID+=offsetCounter/nI;
             }
             offsetCounter/=nI;
@@ -2450,7 +2450,7 @@
 
 //_______________________________________________________________________________________
 
-void      _LikelihoodFunction::RecurseCategory(long blockIndex, long index, long dependance, long highestIndex, hyFloat weight
+void      _LikelihoodFunction::RecurseCategory(long blockIndex, long index, long dependence, long highestIndex, hyFloat weight
 #ifdef _SLKP_LFENGINE_REWRITE_
         ,_SimpleList* siteMultipliers, char runMode, hyFloat *runStorage,
         long branchIndex,              _SimpleList* branchValues
@@ -2459,8 +2459,8 @@
 {
     _CategoryVariable* thisC = (_CategoryVariable*)LocateVar(indexCat.list_data[index]);
     if (index<highestIndex) {
-        if ((!CheckNthBit(dependance,index))||thisC->is_hidden_markov())
-            RecurseCategory (blockIndex, index+1, dependance,highestIndex,weight
+        if ((!CheckNthBit(dependence,index))||thisC->is_hidden_markov())
+            RecurseCategory (blockIndex, index+1, dependence,highestIndex,weight
 #ifdef _SLKP_LFENGINE_REWRITE_
                              ,siteMultipliers,runMode,runStorage
 #endif
@@ -2471,7 +2471,7 @@
             offsetCounter *= nI;
             for (long k = 0; k<nI; k++) {
                 thisC->SetIntervalValue(k);
-                RecurseCategory(blockIndex,index+1,dependance, highestIndex,weight*thisC->GetIntervalWeight(k)
+                RecurseCategory(blockIndex,index+1,dependence, highestIndex,weight*thisC->GetIntervalWeight(k)
 #ifdef _SLKP_LFENGINE_REWRITE_
                                 ,siteMultipliers,runMode,runStorage,branchIndex,branchValues
 #endif
@@ -2698,7 +2698,7 @@
     {
         _Matrix     dependancies (MAX(3,indexDep.lLength),indexInd.lLength,true,true);
         
         // element (i,j) represents the dependance of i-th dep var on the j-th ind var
         // 0 - no dep,
         // 1 -> monotone increase,
         // -1 -> monotone decrease
@@ -7678,7 +7678,7 @@
 
     avl.ReorderList();
 
-    if (templateKind<0) { // remove dependance of the function from the HMM model specifier
+    if (templateKind<0) { // remove dependence of the function from the HMM model specifier
         allVariables.Delete (allVariables.Find(-templateKind-1));
         rankVariables.Delete ((BaseRef)(-templateKind-1));
     }
@@ -2698,7 +2698,7 @@
         _Matrix     dependancies (MAX(3,indexDep.lLength),indexInd.lLength,true,true);
         
-        // element (i,j) represents the dependance of i-th dep var on the j-th ind var
+        // element (i,j) represents the dependence of i-th dep var on the j-th ind var
         // 0 - no dep,
         // 1 -> monotone increase,
